==> apgl-0.6.1.tar.gz: apgl-0.6.1/apgl/graph/test/GeneralVertexListTest.py <==

from apgl.graph.GeneralVertexList import GeneralVertexList
import unittest
import numpy

class GeneralVertexListTest(unittest.TestCase):
    def setUp(self):
        self.numVertices = 10

        self.vList = GeneralVertexList(self.numVertices)


    def testConstructor(self):
        self.assertEquals(self.vList.getNumVertices(), self.numVertices)

    def testSetVertex(self):
        ind = 3;
        value = numpy.array([0.1, 0.5, 0.1])
        self.vList.setVertex(ind, value)

        self.assertEquals((self.vList.getVertex(ind) == value).all(), 1)

    def testClearVertex(self):
        ind = 3;
        value = numpy.array([0.1, 0.5, 0.1])
        self.vList.setVertex(ind, value)

        self.assertEquals((self.vList.getVertex(ind) == value).all(), 1)

        self.vList.clearVertex(3)
        self.assertTrue(self.vList.getVertex(ind) == None)


    def testGetVertices(self):
        vList = GeneralVertexList(self.numVertices)
        vList.setVertex(0, numpy.array([1, 2, 3]))
        vList.setVertex(1, numpy.array([4, 5, 6]))
        vList.setVertex(2, numpy.array([7, 8, 9]))
        vList.setVertex(3, numpy.array([0, 11, 12]))

        self.assertTrue((vList.getVertices([0, 3]) == numpy.array([[1, 2, 3], [0, 11, 12]])).all())
        self.assertTrue((vList.getVertices([3, 0]) == numpy.array([[0, 11, 12], [1, 2, 3]])).all())
        self.assertTrue((vList.getVertices([0, 2]) == numpy.array([[1, 2, 3], [7, 8, 9]])).all())
        self.assertTrue((vList.getVertices([1]) == numpy.array([[4,5,6]])).all())

    def testSetVertices(self):
        vList = GeneralVertexList(self.numVertices)

        vertices = []
        for i in range(self.numVertices):
            vertices.append(i*2)

        vList.setVertices(vertices)

        for i in range(self.numVertices):
            self.assertEquals(vList.getVertex(i), i*2)



    def testGetCopy(self):
        vList = GeneralVertexList(self.numVertices)
        vList.setVertex(0, numpy.array([1, 2, 3]))
        vList.setVertex(1, numpy.array([4, 5, 6]))
        vList.setVertex(2, numpy.array([7, 8, 9]))

        vList2 = vList.copy()
        self.assertTrue((vList.getVertices(range(0, self.numVertices)) == vList2.getVertices(range(0, self.numVertices))))

        vList.setVertex(0, numpy.array([10, 20, 30]))
        self.assertTrue((vList2.getVertex(0) == numpy.array([1, 2, 3])).all())

    def testSubList(self):
        vList = GeneralVertexList(self.numVertices)
        vList.setVertex(0, numpy.array([1, 2, 3]))
        vList.setVertex(1, numpy.array([4, 5, 6]))
        vList.setVertex(2, numpy.array([7, 8, 9]))

        vList2 = vList.subList([0, 2])

        self.assertEquals(vList2.getNumVertices(), 2)
        self.assertTrue((vList.getVertices([0, 2]) == vList2.getVertices([0, 1])))

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(VertexListTest)
    unittest.TextTestRunner(verbosity=2).run(suite)

==> apgl-0.6.5.tar.gz: apgl-0.6.5/apgl/graph/test/GeneralVertexListTest.py <==

from apgl.graph.GeneralVertexList import GeneralVertexList
from apgl.util.PathDefaults import PathDefaults 
import unittest
import numpy

class GeneralVertexListTest(unittest.TestCase):
    def setUp(self):
        self.numVertices = 10

        self.vList = GeneralVertexList(self.numVertices)


    def testConstructor(self):
        self.assertEquals(self.vList.getNumVertices(), self.numVertices)

    def testSetVertex(self):
        ind = 3;
        value = numpy.array([0.1, 0.5, 0.1])
        self.vList.setVertex(ind, value)

        self.assertEquals((self.vList.getVertex(ind) == value).all(), 1)

    def testClearVertex(self):
        ind = 3;
        value = numpy.array([0.1, 0.5, 0.1])
        self.vList.setVertex(ind, value)

        self.assertEquals((self.vList.getVertex(ind) == value).all(), 1)

        self.vList.clearVertex(3)
        self.assertTrue(self.vList.getVertex(ind) == None)


    def testGetVertices(self):
        vList = GeneralVertexList(self.numVertices)
        vList.setVertex(0, numpy.array([1, 2, 3]))
        vList.setVertex(1, numpy.array([4, 5, 6]))
        vList.setVertex(2, numpy.array([7, 8, 9]))
        vList.setVertex(3, numpy.array([0, 11, 12]))

        self.assertTrue((vList.getVertices([0, 3]) == numpy.array([[1, 2, 3], [0, 11, 12]])).all())
        self.assertTrue((vList.getVertices([3, 0]) == numpy.array([[0, 11, 12], [1, 2, 3]])).all())
        self.assertTrue((vList.getVertices([0, 2]) == numpy.array([[1, 2, 3], [7, 8, 9]])).all())
        self.assertTrue((vList.getVertices([1]) == numpy.array([[4,5,6]])).all())

    def testSetVertices(self):
        vList = GeneralVertexList(self.numVertices)

        vertices = []
        for i in range(self.numVertices):
            vertices.append(i*2)

        vList.setVertices(vertices)

        for i in range(self.numVertices):
            self.assertEquals(vList.getVertex(i), i*2)



    def testGetCopy(self):
        vList = GeneralVertexList(self.numVertices)
        vList.setVertex(0, numpy.array([1, 2, 3]))
        vList.setVertex(1, numpy.array([4, 5, 6]))
        vList.setVertex(2, numpy.array([7, 8, 9]))

        vList2 = vList.copy()
        self.assertTrue((vList.getVertices(list(range(0, self.numVertices))) == vList2.getVertices(list(range(0, self.numVertices)))))

        vList.setVertex(0, numpy.array([10, 20, 30]))
        self.assertTrue((vList2.getVertex(0) == numpy.array([1, 2, 3])).all())

    def testSubList(self):
        vList = GeneralVertexList(self.numVertices)
        vList.setVertex(0, numpy.array([1, 2, 3]))
        vList.setVertex(1, numpy.array([4, 5, 6]))
        vList.setVertex(2, numpy.array([7, 8, 9]))

        vList2 = vList.subList([0, 2])

        self.assertEquals(vList2.getNumVertices(), 2)
        self.assertTrue((vList.getVertices([0, 2]) == vList2.getVertices([0, 1])))

    def testSaveLoad(self):
        try:
            vList = GeneralVertexList(self.numVertices)
            vList.setVertex(0, "abc")
            vList.setVertex(1, 12)
            vList.setVertex(2, "num")

            tempDir = PathDefaults.getTempDir()
            fileName = tempDir + "vList"

            vList.save(fileName)

            vList2 = GeneralVertexList.load(fileName)

            for i in range(self.numVertices):
                self.assertEquals(vList.getVertex(i), vList2.getVertex(i))
        except IOError as e:
            print(e)
            pass 

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(VertexListTest)
    unittest.TextTestRunner(verbosity=2).run(suite)
